@@ -21,13 +21,13 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: convert.rb,v 1.1.1.1 2004/07/06 11:44:32 fukuoka Exp $
+  $Id: convert.rb 10 2004-07-06 11:44:32Z fukuoka $
 =end
 
 ## usage: ruby convert.rb project-id new-store-type
 
-kagemai_root = "/usr/share/kagemai/"
-config_file  = "/etc/kagemai/kagemai.conf"
+kagemai_root = File.dirname(File.dirname(File.expand_path(__FILE__))) # setup
+config_file  = "#{kagemai_root}/kagemai.conf" # setup
 
 $: << "#{kagemai_root}/lib"
 require 'kagemai/config'
