@@ -3,7 +3,7 @@
 =begin
   mailif.rb - KAGEMAI mail interface
 
-  Copyright(C) 2002-2004 FUKUOKA Tomoyuki.
+  Copyright(C) 2002-2005 FUKUOKA Tomoyuki.
 
   This file is part of KAGEMAI.  
 
@@ -21,21 +21,33 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: mailif.rb,v 1.3.2.8 2005/01/15 13:52:54 fukuoka Exp $
+  $Id: mailif.rb 409 2008-02-23 14:07:23Z fukuoka $
 =end
 
 ## usage: ruby mailif.rb project-id
 ##  * mailif.rb reads a mail from stdin.
 
-kagemai_root = "/usr/share/kagemai/"
-config_file  = "/etc/kagemai/kagemai.conf"
+kagemai_root = File.dirname(File.dirname(File.expand_path(__FILE__))).untaint # setup
+config_file  = "#{kagemai_root}/html/kagemai.conf" # setup
 
-$LOGFILE = "/tmp/kagemai.log"  # setup
+if $0 == __FILE__ && ARGV.size == 3 then  
+  project_id =  ARGV.shift
+  opt = ARGV.shift
+  if opt == '-c' then
+    config_file = ARGV.shift
+  end
+  ARGV.unshift project_id
+end
 
 $:.unshift("#{kagemai_root}/lib")
 require 'kagemai/config'
 Kagemai::Config.initialize(kagemai_root, config_file)
 
+$LOGFILE = "/tmp/mailif.log"  # setup
+if File.exist?(config_file) then
+  $LOGFILE = "#{Kagemai::Config[:project_dir]}/mailif.log"
+end
+
 require 'tempfile'
 
 require 'rmail/parser'
@@ -73,7 +85,7 @@ module Kagemai
   class MailApp
 
     def initialize(project_id, lang, project_dir = Config[:project_dir])
-      MessageBundle.open(Config[:resource_dir], lang, Config[:message_bundle_name])
+      MessageBundle.open(Config[:resource_dir], lang, Config[:message_bundle_name], false)
       @bts = BTS.new(project_dir)
       @project = @bts.open_project(project_id)
       
@@ -186,7 +198,7 @@ module Kagemai
     end
     
     def kconv(str)
-      Kconv.kconv(str, Kconv::EUC, Kconv::JIS)      
+      KKconv.conv(str, KKconv::EUC, KKconv::JIS)      
     end
     
     def get_report(msg_id, title)
@@ -236,16 +248,11 @@ module Kagemai
         file = Tempfile.new('kagemai_tempfile')
         file.binmode
         begin
-          class << file
-            attr(:original_filename, true)
-          end
-          file.original_filename = fileinfo.name
-          
           file.write(value)
           file.flush
           file.rewind
           
-          fileinfo.seq = @project.store_attachment(file)
+          fileinfo.seq = @project.store_attachment(file, fileinfo)
           felement.add_fileinfo(fileinfo)
         ensure
           file.close
