@@ -21,7 +21,7 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: migrate.rb,v 1.1.1.1 2004/07/06 11:44:32 fukuoka Exp $
+  $Id: migrate.rb 371 2008-02-20 11:53:39Z fukuoka $
 =end
 
 ## NOTE:
@@ -29,8 +29,8 @@
 ##  chown ɬפ뤫⤷ʤ
 
 #  0.8 ξ
-kagemai_root = "/usr/share/kagemai/"
-config_file  = "/etc/kagemai/kagemai.conf"
+kagemai_root = File.dirname(File.dirname(File.expand_path(__FILE__))).untaint # setup
+config_file  = "#{kagemai_root}/kagemai.conf" # setup
 
 #  0.7  global.rb 
 old_lib = "" # setup
@@ -44,7 +44,7 @@ end
 work_dir = "/tmp/kagemai_migrate_#{Process.pid}" # setup
 
 require 'cgi'    # for CGI::escape, CGI::unescape
-require 'ftools'
+require 'fileutils'
 
 # ƵŪʥǥ쥯ȥκ
 def Dir.remove_dir(dir)
