@@ -4,11 +4,11 @@
 
   usage: ruby install_ja.rb [previous-install-logfile]
 
-  $Id: install_ja.rb,v 1.3.2.2 2005/01/22 19:34:53 fukuoka Exp $
+  $Id: install_ja.rb 472 2008-02-29 18:05:30Z fukuoka $
 =end
 
 # 󥹥ȡ Revision number
-$revision = '$Revision: 1.3.2.2 $'.sub(/^\$Revisio.: (\d.+) \$$/, '\1')
+$revision = '$Revision: 472 $'.sub(/^\$Revisio.: (\d.+) \$$/, '\1')
 
 ### ǡ¸ǥ쥯ȥʤɤ user  group
 ### ꤷʤˤϡȥȤƤ
@@ -48,6 +48,7 @@ $admin_passwd_file = "#{$passwd_dir}/admin.passwd" # ԤΥѥɥե
 
 $project_dir     = "#{$data_dir}/project"     # ץȤΥǡ
 $mailif_logfile  = "#{$data_dir}/mailif.log"  # mailif.rb ѥե
+$tmp_dir         = "#{$project_dir}/_tmp"     # åʤɤΰե
 
 $config_file = "#{$html_dir}/kagemai.conf" # ե
 
@@ -55,7 +56,7 @@ $config_file = "#{$html_dir}/kagemai.conf" # ե
 ###########################################################################
 ## 鲼ϡ̤ԽɬפϤޤ
 
-require 'ftools'
+require 'fileutils'
 require 'digest/md5'
 
 ## 䤤碌
@@ -73,7 +74,7 @@ end
 
 $ifiles = {}
 if File.exist?($install_logfile) then
-  msg = "Υ󥹥ȡĤޤ\nƱǥ󥹥ȡ뤷ޤ"
+  msg = "A previous installation log file was found.  Shall I use the same settings as before?"
   if query(msg, true) then
     src = File.open($install_logfile){|file| file.read}
     eval(src)
@@ -108,7 +109,7 @@ dirs = %w(
 
 dirs.each do |name|
   dir = eval("$#{name}")
-  File.mkpath(dir)
+  FileUtils.mkpath(dir)
   File.chown($uid, $gid, dir)
 end
 File.chmod($dir_mode, $data_dir)
@@ -149,7 +150,7 @@ $logfile.puts
 ## ե digest η׻
 def digest(filename)
   src = File.open(filename) {|file| file.read}
-  digest = Digest::MD5.new(src).hexdigest
+  digest = Digest::MD5::hexdigest(src)
 end
 
 ## եΥԡ
@@ -166,7 +167,7 @@ def copy(category, filename)
   end
 
   unless File.exist?(File.dirname(to)) then
-    File.mkpath(File.dirname(to))
+    FileUtils.mkpath(File.dirname(to))
   end
 
   # 󥹥ȡƱե뤬¸ߤơ
@@ -179,7 +180,7 @@ def copy(category, filename)
     end
   end
 
-  File.copy(filename, to, true)
+  FileUtils.copy(filename, to, {:verbose => true})
 
   stat = File.stat(filename)
   File.chmod(stat.mode, to)
@@ -242,7 +243,7 @@ $stdout.flush
 bin_files = []
 ['bin', 'html', 'html_i'].each do |category|
   $files[category].each do |k, v|
-    next unless /\.(cgi|rb)$/ =~ k
+    next unless /\.(cgi|fcgi|rb)$/ =~ k
     from, to = v
     bin_files << to
   end
@@ -260,7 +261,7 @@ puts "Update kagemai paths:"
 $stdout.flush
 ['bin', 'html'].each do |category|
   $files[category].each do |k, v|
-    next unless /\.(cgi|rb)$/ =~ k
+    next unless /\.(cgi|fcgi|rb)$/ =~ k
     file = v[1]
     puts "  #{file}"
     update_file(file, /^kagemai_root\s*=.*\# setup$/, "kagemai_root = '#{$root_dir}'")
@@ -294,6 +295,7 @@ unless File.exist?($config_file) then
   File.open($config_file, 'w') do |file|
     file.puts "module Kagemai"
     file.puts "  Config[:project_dir] = '#{$project_dir}'"
+    file.puts "  Config[:tmp_dir] = '#{$tmp_dir}'"
     file.puts "end"
   end
   File.open($config_file + "~", 'w') do |file|
@@ -334,7 +336,7 @@ $stdout.flush
 puts ""
 [$user_passwd_file, $admin_passwd_file].each do |passwd|
   unless File.exist?(passwd) then
-    if query(" '#{passwd}' ޤ", true) then
+    if query("Create '#{passwd}'?", true) then
       print 'name: '
       $stdout.flush
       name = gets.strip
