@@ -18,11 +18,9 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-  $Id: bts.rb,v 1.2.2.4 2005/01/24 11:59:04 fukuoka Exp $
 =end
 
-require 'ftools'
+require 'fileutils'
 
 require 'kagemai/config'
 require 'kagemai/project'
@@ -48,17 +46,25 @@ module Kagemai
       
       if Config[:enable_postgres] then
         require 'kagemai/pgstore'
-        Config[:stores] << Kagemai::PostgresStore
+        require 'kagemai/pgstore3'
+        Config[:stores] << Kagemai::PostgresStore  # obsolete
+        Config[:stores] << Kagemai::PostgresStore3
       end      
       
       if Config[:enable_mssql] then
         require 'kagemai/mssqlstore'
+        require 'kagemai/mssqlstore3'
         Config[:stores] << Kagemai::MSSqlStore
+        Config[:stores] << Kagemai::MSSqlStore3
       end      
 
       if Config[:enable_mysql] then
         require 'kagemai/mysqlstore'
-        Config[:stores] << Kagemai::MySQLStore
+        require 'kagemai/mysqlstore2'
+        require 'kagemai/mysqlstore3'
+        Config[:stores] << Kagemai::MySQLStore  # obsolete
+        Config[:stores] << Kagemai::MySQLStore2 # obsolete
+        Config[:stores] << Kagemai::MySQLStore3
       end      
       
       # set default mailer
@@ -70,8 +76,13 @@ module Kagemai
       # make project dir
       id = options.fetch('id')
       dir = "#{@project_dir}/#{id}"
-      File.mkpath(dir)
-      File.chmod2(Config[:dir_mode], dir)
+      FileUtils.mkpath(dir)
+      FileUtils.chmod2(Config[:dir_mode], dir)
+      
+      # make cache_dir
+      cache_dir = "#{dir}/cache"
+      FileUtils.mkpath(cache_dir)
+      FileUtils.chmod2(Config[:dir_mode], cache_dir)
       
       begin
         # save configurations
@@ -83,8 +94,16 @@ module Kagemai
         template_base = "#{template_dir(lang)}/#{template}"
         rtype_template_filename = "#{template_base}/reporttype.xml"
         rtype_filename = "#{dir}/reporttype.xml"
-        File.copy(rtype_template_filename, rtype_filename)
-        File.chmod2(Config[:file_mode], rtype_filename)
+        FileUtils.copy(rtype_template_filename, rtype_filename)
+        FileUtils.chmod2(Config[:file_mode], rtype_filename)
+        
+        # copy message bundle
+        mb_template_filename = "#{template_base}/#{Config[:message_bundle_name]}"
+        mb_filename = "#{dir}/#{Config[:message_bundle_name]}"
+        if File.exist?("#{template_base}/messages") then
+          FileUtils.copy(mb_template_filename, mb_filename)
+          FileUtils.chmod2(Config[:file_mode], mb_filename)
+        end
         
         # copy message bundle
         mb_template_filename = "#{template_base}/#{Config[:message_bundle_name]}"
@@ -97,42 +116,51 @@ module Kagemai
         # copy  templates
         template_dir = "#{dir}/template"
         Dir.mkdir(template_dir)
-        File.chmod2(Config[:dir_mode], template_dir)
+        FileUtils.chmod2(Config[:dir_mode], template_dir)
         if File.exist?("#{template_base}/template") then
           Dir.glob("#{template_base}/template/[A-Za-z0-9]*") do |path|
             next if path =~ /CVS$/
             path = Util.untaint_path(path)
             dist = "#{dir}/template/#{File.basename(path)}"
-            File.copy(path, dist)
-            File.chmod2(Config[:file_mode], dist)
+            FileUtils.copy(path, dist)
+            FileUtils.chmod2(Config[:file_mode], dist)
           end
         end
         
         # copy scripts
         script_dir = "#{dir}/script"
         Dir.mkdir(script_dir)
-        File.chmod2(Config[:dir_mode], script_dir)
+        FileUtils.chmod2(Config[:dir_mode], script_dir)
         if File.exist?("#{template_base}/script") then
           Dir.glob("#{template_base}/script/[A-Za-z0-9]*") do |path|
             next if path =~ /CVS$/
             path = Util.untaint_path(path)
             dist = "#{dir}/script/#{File.basename(path)}"
-            File.copy(path, dist)
-            File.chmod2(Config[:file_mode], dist)
+            FileUtils.copy(path, dist)
+            FileUtils.chmod2(Config[:file_mode], dist)
           end
         end
         
         # make include file for mail interface
         mail_include_file = "#{dir}/include"
+        mailif = "#{Config.root}/bin/mailif.rb"
+        mailif_opt = "#{id} -c #{Config.config_file}"
         File.open(mail_include_file, 'wb') do |file|
-          file.puts %Q!"|#{$RUBY_BINARY} #{Config.root}/bin/mailif.rb #{id}"!
+          file.puts %Q!"|#{$RUBY_BINARY} #{mailif} #{mailif_opt}"!
         end
-        File.chmod2(0644, mail_include_file)
+        FileUtils.chmod2(0644, mail_include_file)
         
         # make mail spool
         mail_spool_dir = "#{dir}/mail"
         Dir.mkdir(mail_spool_dir)
-        File.chmod2(Config[:dir_mode], mail_spool_dir)
+        FileUtils.chmod2(Config[:dir_mode], mail_spool_dir)
+        
+        # make cache dir
+        cache_dir = "#{dir}/cache"
+        unless File.exist?(cache_dir) then
+          Dir.mkdir(cache_dir)
+          File.chmod2(Config[:dir_mode], cache_dir)
+        end
         
         # initialize store
         report_type = ReportType.load(rtype_filename)
@@ -161,10 +189,10 @@ module Kagemai
         work_db_manager_class = DEFAULT_DB_MANAGER_CLASS
         
         work_db_manager = nil
-        attachment_name_map = {}
+        attachment_info_map = {}
         
         if old_db_manager_class != work_db_manager_class then
-          File.makedirs(work_dir)
+          FileUtils.makedirs(work_dir)
           work_db_manager_class.create(work_dir, id, report_type, charset)
           work_db_manager = work_db_manager_class.new(work_dir, id, report_type, charset)
           
@@ -172,7 +200,8 @@ module Kagemai
           
           seq_map = {}
           db_manager.each_attachment do |attachment, seq|
-            seq_map[seq] = work_db_manager.store_attachment(attachment)
+            info = Store::FileInfo.new("unknowon", attachment.stat.size)
+            seq_map[seq] = work_db_manager.store_attachment(attachment, info)
           end
           
           db_manager.each(report_type) do |report|
@@ -181,7 +210,7 @@ module Kagemai
                 if etype.kind_of?(FileElementType) then
                   m.element(etype_id).each do |fileinfo|
                     fileinfo.seq = seq_map[fileinfo.seq]
-                    attachment_name_map[fileinfo.seq] = fileinfo.name
+                    attachment_info_map[fileinfo.seq] = fileinfo.dup
                   end
                 end
               end
@@ -189,7 +218,7 @@ module Kagemai
             end
             work_db_manager.store_with_id(report)
           end
-
+          
           db_manager.close()
         else
           work_db_manager = old_db_manager_class.new(source_dir, id, report_type, charset)
@@ -199,7 +228,7 @@ module Kagemai
               m.each do |etype, etype_id, etype_name, value|
                 if etype.kind_of?(FileElementType) then
                   m.element(etype_id).each do |fileinfo|
-                    attachment_name_map[fileinfo.seq] = fileinfo.name
+                    attachment_info_map[fileinfo.seq] = fileinfo.dup
                   end
                 end
               end
@@ -213,12 +242,7 @@ module Kagemai
         
         seq_map = {}
         work_db_manager.each_attachment do |attachment, seq|
-          eval <<-AEND
-          def attachment.original_filename()
-            '#{attachment_name_map[seq].untaint}'
-          end
-          AEND
-          seq_map[seq] = db_manager.store_attachment(attachment)
+          seq_map[seq] = db_manager.store_attachment(attachment, attachment_info_map[seq])
         end
         
         db_manager.transaction {
@@ -257,7 +281,8 @@ module Kagemai
           Logger.debug("BTS", $@)
         end
       end
-      
+
+      sleep(1)
       old_db_manager_class.destroy(source_dir, id)
     end
     
@@ -270,7 +295,7 @@ module Kagemai
         project.db_manager_class.destroy(path, id)
         Dir.delete_dir(path)
       else
-        File.makedirs(attic_dir())
+        FileUtils.makedirs(attic_dir())
         del_base_name = del_name
         
         del_count = 1
@@ -280,6 +305,8 @@ module Kagemai
         end
         File.rename(path, del_name)
       end
+      Thread.current[:Project] = nil
+      
       [project, del_name]
     end
     
@@ -304,6 +331,13 @@ module Kagemai
       projects.sort(){|a, b| a.name <=> b.name}.each(&block)
     end
     
+    def invalidate_cache()
+      Dir.glob("#{@project_dir}/[A-Za-z0-9]*/cache/*.compile") do |path|
+        path.untaint
+        File.unlink path
+      end
+    end
+    
     def count_project()
       n = 0
       each_project() { n += 1 }
@@ -320,7 +354,7 @@ module Kagemai
     end
     
     def count_store()
-      Config[:stores].size
+      Config[:stores].select{|s| !s.obsolete?}.size
     end
     
     def validate_store(store_name)
