@@ -18,8 +18,6 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-  $Id: legend.rb,v 1.3.2.1 2005/01/26 13:47:38 fukuoka Exp $
 =end
 
 module Kagemai
@@ -38,12 +36,13 @@ module Kagemai
       
       @shadow_offset_x = 4
       @shadow_offset_y = 4
-
-      @conv = IconvFactory.create(Config[:gd_charset], Config[:charset], true)
+      
+      @kconv_to   = Config[:gd_charset]
+      @kconv_from = Config[:charset]
     end
 
     def add(text, color)
-      @items << LegendItem.new(@conv.iconv(text), @ptsize, color, @font)
+      @items << LegendItem.new(text.ckconv(@kconv_to, @kconv_from), @ptsize, color, @font)
     end
   
     def add_item(legend_item)
