@@ -1,7 +1,6 @@
 =begin
   kagemai.rb -- KAGEMAI : A Bug Tracking System.
-
-  Copyright(C) 2002-2005 FUKUOKA Tomoyuki.
+  Copyright(C) 2002-2008 FUKUOKA Tomoyuki.
 
   This file is part of KAGEMAI.  
 
@@ -18,10 +17,15 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-  $Id: kagemai.rb,v 1.2.2.6 2005/01/27 13:44:51 fukuoka Exp $
 =end
 
+begin
+  require 'rubygems'
+rescue LoadError 
+  # ignore
+end
+
+require 'fileutils'
 require 'kagemai/config'
 require 'kagemai/bts'
 require 'kagemai/cgi/action'
@@ -29,7 +33,7 @@ require 'kagemai/error'
 
 module Kagemai
   CODENAME = 'Haru'
-  VERSION  = '0.8.6'
+  VERSION  = '0.8.8'
   URL      = 'http://www.daifukuya.com/kagemai/'
   
   class CGIApplication
@@ -46,15 +50,20 @@ module Kagemai
       @cgi = cgi
       @mode = mode
       @bts = BTS.new(Config[:project_dir])
-      @actions, @default_action = load_actions(Config[:action_dir])
       @project = nil
       
-      @lang = @cgi.get_param('lang', Config[:language])
+      # check tmpdir
+      unless File.exist?(Config[:tmp_dir]) then
+        FileUtils.mkpath(Config[:tmp_dir])
+        FileUtils.chmod(Config[:dir_mode] & 02770, Config[:tmp_dir])
+      end
+      
+      @lang = Util.untaint_path(@cgi.get_param('lang', Config[:language]))
       MessageBundle.open(Config[:resource_dir], @lang, Config[:message_bundle_name])
       
       # initialize TLS
       Thread.current[:element_renderer] = {}
-      
+            
       # Store application object to TLS.
       Thread.current[:CGIApplication] = self
       CGIApplication.instance()
@@ -63,7 +72,9 @@ module Kagemai
     
     def action()
       name = @cgi.get_param('action', '')
+      @actions, @default_action = Action::load(Config[:action_dir])
       action_class = name.empty? ? @default_action : @actions[name]
+      
       if action_class then
         action = action_class.new(@cgi, @bts, @mode, @lang)
         project = action.project
@@ -71,7 +82,7 @@ module Kagemai
         type = action.cache_type
         key = @mode.url + ':' + action.cache_key
         
-        if project && Config[:use_html_cache] then
+        if project && Config[:use_html_cache] && !$KAGEMAI_DEBUG then
           result = project.load_cache(type, key)
         end
         result = action.execute() unless result
@@ -111,30 +122,6 @@ module Kagemai
     end
     
     private
-    @@load_mutex = Mutex.new
-    
-    def load_actions(dir)
-      @@load_mutex.synchronize {
-        # load actions
-        Dir.glob(dir + "/*\.rb").each do |action_script|
-          require action_script.untaint
-        end
-        
-        # init action map
-        actions = Hash.new
-        default = nil
-        ObjectSpace.each_object(Class) do |class_obj|
-          ancestors = class_obj.ancestors
-          ancestors.delete(class_obj)
-          if ancestors.include?(Kagemai::Action) then
-            actions[class_obj.name] = class_obj
-            default = class_obj if class_obj.default?
-          end
-        end        
-        raise InitializeError, 'No default action loaded.' unless default
-        [actions, default]
-      }
-    end
     
     def do_search(project, keywords, attr_cond, case_insensitive, limit, offset, order)
       search_elements = Hash.new(false)
