@@ -20,23 +20,28 @@
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   
-  $Id: mysqlstore.rb,v 1.1.2.13 2005/01/22 21:16:55 fukuoka Exp $
+  $Id: mysqlstore.rb 412 2008-02-23 14:54:23Z fukuoka $
 =end
 
 require 'kagemai/store'
 require 'kagemai/dbistore'
 require 'kagemai/util'
 require 'tempfile'
+require 'time'
 
 module Kagemai  
   class MySQLStore < Store
     include BaseDBIStore
     
+    def self.obsolete?()
+      true
+    end
+    
     DBI_DRIVER_NAME = 'Mysql'
 
     SQL_TYPES = {
-      'varchar' => SQLType.new('varchar', 255, 'binary'),
-      'text'    => SQLType.new('blob', nil, nil),
+      'varchar' => SQLType.new('varchar', 'binary'),
+      'text'    => SQLType.new('blob', nil),
     }
     
     SQL_SEARCH_OP = {
@@ -44,6 +49,10 @@ module Kagemai
       false    => "'0'",
       'regexp' => 'regexp',
     }
+
+    def self.disp_name()
+      'old MySQLStore(obsolete)'
+    end
     
     def self.description()
       MessageBundle[:MySQLStore]
@@ -73,7 +82,6 @@ module Kagemai
       tables = %w(reports messages attachments)
       store  = self.new(dir, project_id, nil, nil)
       store.execute() do |db|
-        db.do("drop index #{project_id}_rid_index on #{store.table_name('messages')}")
         tables.each do |table|
           db.do("drop table #{store.table_name(table)}")
         end
@@ -148,7 +156,10 @@ module Kagemai
       DBI.connect(@driver_url, @user, @pass, @params) do |db|
         @params.each {|k, v| db[k] = v}
         dt = db.select_one("select now()")[0]
-        mysql_now   = Time.local(dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second)
+        if dt.kind_of?(String) then
+          dt = Time.parse(dt)
+        end
+        mysql_now   = Time.local(dt.year, dt.month, dt.day, dt.hour, dt.min, dt.sec)
         @local_time = (Time.now - mysql_now).abs < (60 * 30)
       end
     end
@@ -205,13 +216,13 @@ module Kagemai
       store(report)
     end
     
-    def store_attachment(attachment)
+    def store_attachment(attachment, fileinfo)
       execute do |db|
         attach_id = nil
         db.transaction {
-          name = attachment.original_filename
-          size = attachment.stat.size
-          ctime = attachment.stat.ctime.strftime('%m %d %H:%M:%S %Z %Y')
+          name = fileinfo.name
+          size = fileinfo.size
+          ctime = sql_time(attachment.stat.ctime)
           data = attachment.read
           
           sql =  "insert into #{table_name('attachments')} (name,size,create_time,data)"
@@ -314,7 +325,7 @@ module Kagemai
       execute do |db|
         where_clause = last_message_id_where_clause()
         query =  "select report_id from #{table_name('messages')}"
-        query += " where #{col_name(attr_id)} = '#{choice_id}' and (#{where_clause}) order by id"
+        query += " where #{col_name(attr_id)} regexp '#{choice_id}' and (#{where_clause}) order by id"
         rid_set = db.select_all(query)
         reports = rid_set.collect {|rid| load_dummy(@report_type, rid[0])}
       end
