@@ -1,7 +1,7 @@
 =begin
   util.rb - utilities
   
-  Copyright(C) 2002-2005 FUKUOKA Tomoyuki.
+  Copyright(C) 2002-2008 FUKUOKA Tomoyuki.
   
   This file is part of KAGEMAI.  
   
@@ -18,26 +18,15 @@
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-  
-  $Id: util.rb,v 1.7.2.4 2005/01/20 11:32:51 fukuoka Exp $
 =end
 
+require 'fileutils'
 require 'erb'
 require 'cgi'
-require 'parsedate'
 require 'thread'
 require 'kagemai/error'
 require 'kagemai/logger'
-
-class Array
-  unless method_defined?(:sort_by) then
-    def sort_by()
-      self.collect {|i| [yield(i), i] }.
-        sort {|a,b| a[0] <=> b[0] }.
-        collect! {|i| i[1]}
-    end
-  end
-end
+require 'kagemai/template_cache'
 
 class String
   def quote(prefix = '> ')
@@ -61,12 +50,30 @@ class String
   end
 end
 
+if RUBY_VERSION < "1.9.0" then
+  require 'parsedate' 
+else
+  require 'time'
+end
+
+if RUBY_VERSION < "1.9.0"
+  require 'parsedate' 
+else
+  module ParseDate
+    require 'date/format'
+    def ParseDate.parsedate(date, cyear)
+      h = Date._parse(date)
+      [h[:year], h[:mon], h[:mday], h[:hour], h[:min], h[:sec], [:zone], [:wday]]
+    end
+  end
+end
+
 class Time
   @@week_of_days = nil
   
   def self.parsedate(date, cyear = false)
-    # from Ruby FAQ.
     ary = ParseDate.parsedate(date, cyear)
+    
     if ary.size >= 6 && ary[6] == 'GMT' then
       Time::gm(*ary[0..-3])
     else
@@ -75,8 +82,7 @@ class Time
   end
   
   def format()
-    # Ūˤϡlang ˱ƥեޥåȤ򤫤
-    self.strftime("%Y/%m/%d %H:%M:%S")
+    self.strftime("%Y-%m-%d %H:%M:%S")
   end
   
   def format_date(lang = 'ja')
@@ -98,15 +104,17 @@ def File.create(path)
   File.open(path, 'wb') {|file| }
 end
 
-def File.chmod2(mode, *filenames)
-  begin
-    chmod_files = filenames.find_all{|name| (File.stat(name).mode & 07777) != (mode & 07777)}
-    File.chmod(mode, *chmod_files) if chmod_files.size > 0
-  rescue SystemCallError => e
-    prefix = 'kagemai: '
-    bt = e.backtrace.join("\n" + prefix + '  ')
-    STDERR.puts "#{prefix} #{e} (#{e.class})"
-    STDERR.puts "#{prefix} #{bt}"
+module FileUtils
+  def FileUtils.chmod2(mode, *filenames)
+    begin
+      chmod_files = filenames.find_all{|name| (File.stat(name).mode & 07777) != (mode & 07777)}
+      FileUtils.chmod(mode, *chmod_files) if chmod_files.size > 0
+    rescue SystemCallError => e
+      prefix = 'kagemai: '
+      bt = e.backtrace.join("\n" + prefix + '  ')
+      STDERR.puts "#{prefix} #{e} (#{e.class})"
+      STDERR.puts "#{prefix} #{bt}"
+    end
   end
 end
 
@@ -124,26 +132,8 @@ def Dir.delete_dir(dir)
   Dir.rmdir(dir)
 end
 
-class ERB
-  alias set_eoutvar_orig set_eoutvar
-
-  def set_eoutvar(compiler, eoutvar = '_erbout')
-    compiler.put_cmd = "#{eoutvar} << "
-
-    cmd = []
-    cmd.push "#{eoutvar} = []"
-    
-    compiler.pre_cmd = cmd
-
-    cmd = []
-    cmd.push("#{eoutvar}.join")
-
-    compiler.post_cmd = cmd
-  end
-end
-
 module Kagemai
-  module Util
+  module Util    
     def Util.safe(level = 4)
       result = nil
       Thread.start {
@@ -154,18 +144,18 @@ module Kagemai
     end
     
     def Util.erb_eval_file(filename, binding = TOPLEVEL_BINDING)
-      src = open(filename, 'rb') {|file| ERB.new(file.read.gsub(/\r\n/, "\n")).src}
+      src = TemplateCache::open(Thread.current[:Project], filename) {|file|
+        ERB.new(file.read.gsub(/\r\n/, "\n")).src
+      }
       eval(src.untaint, binding, filename)
     end
     
     def Util.eval_template(filename, template_dir, lang, b = TOPLEVEL_BINDING)
-      Logger.debug('Util', "eval_template: filename = #{filename.inspect}")
       dirs = ["#{Config[:resource_dir]}/#{lang}/template/#{Config[:default_template_dir]}"]
       dirs.unshift(template_dir) if template_dir
       dirs.each do |dir|
-        Logger.debug('Util', "eval_template: look up in directory: #{dir.inspect}")
         path = dir + '/' + filename
-        if FileTest.exist?(path)
+        if File.exist?(path)
           return erb_eval_file(path, b)
         end
       end
